#!/usr/bin/env python3

"""Converts a CUE file to the meta format expected by aNONradio."""

# Copyright (c) 2022 Mark Cornick
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import re
import sys

import click


def cue_to_meta(cuefile, metafile):
    title = None
    performer = None
    timestamp = None

    for line in cuefile.readlines():
        title_re = re.search(r'^    TITLE "(.*)"$', line)
        performer_re = re.search(r'^    PERFORMER "(.*)"$', line)
        index_re = re.search(r"^    INDEX 01 (.*)$", line)
        if title_re:
            title = title_re[1]
        if performer_re:
            performer = performer_re[1]
        if index_re:
            time_re = re.search(r"^(..):(..):..$", index_re[1])
            timestamp = "00{}{}".format(time_re[1], time_re[2])
        if title and performer and timestamp:
            metafile.write("{}:{} - {}\n".format(timestamp, performer, title))
            title = None
            performer = None
            timestamp = None


@click.command()
@click.argument("cuefile", type=click.File("r"))
@click.argument("metafile", type=click.File("w"))
def cli(cuefile, metafile):
    """Convert CUEFILE to meta format as METAFILE."""
    cue_to_meta(cuefile, metafile)
